@@ -1,7 +1,9 @@
 from .Job import Job
 from .JobConfiguration import JobConfiguration
+from .JobDefinition import JobDefinition
 
 __all__ = [
-    'Job'
+    'Job',
     'JobConfiguration',
+    'JobDefinition',
 ]
\ No newline at end of file
