@@ -3,10 +3,10 @@ from AIH_SDK.Designations.DesignationsObject import DesignationsObject
 
 class Design(DesignationsObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.1'):
         super().__init__()
         self._endpoint = 'designs'
-
+        self._version = api_version
 
     def get_objects(self, parameters:dict={}):
         """
