@@ -3,10 +3,10 @@ from AIH_SDK.Designations.DesignationsObject import DesignationsObject
 
 class Schema(DesignationsObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.1'):
         super().__init__()
         self._endpoint = 'schemas'
-
+        self._version = api_version
     
     def get_nodes(self, depth=1):
         """
