@@ -3,11 +3,11 @@ from AIH_SDK.Designations.DesignationsObject import DesignationsObject
 
 class Structure(DesignationsObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.1'):
         super().__init__()
         self._endpoint = 'structures'
         self._object_name = 'StructureDTO'
-
+        self._version = api_version
     
     def get_nodes(self, depth=1):
         """
