@@ -7,6 +7,8 @@ from .Activity import Activity, Input, ActivityMediaReference
 from .Deviation import Deviation
 from .Media import Media
 from .MediaReference import MediaReference
+from .ActivityTemplate import ActivityTemplate, TemplateInput
+from .ActivityType import ActivityType
 
 
 __all__ = [
@@ -23,5 +25,8 @@ __all__ = [
     'WorkTemplateActivity',
     'Media',
     'MediaReference',
-    'ActivityMediaReference'
+    'ActivityMediaReference',
+    'TemplateInput',
+    'ActivityTemplate',
+    'ActivityType'
 ]
\ No newline at end of file
