@@ -4,10 +4,11 @@ from AIH_SDK import AIHExceptions as AIHE
 
 class Classification(MonitorsObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.0'):
         super().__init__()
         self._endpoint = 'Classifications'
-    
+        self._version = api_version
+        
     def get_elements(self, classification_id=None):
         if not classification_id:
             if type(self.value) == dict:
