@@ -3,10 +3,10 @@ from AIH_SDK.Monitors.MonitorsObject import MonitorsObject
 
 class ModelDefinition(MonitorsObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.0'):
         super().__init__()
         self._endpoint = 'ModelDefinitions'
-    
+        self._version = api_version
 
     def get(self, name: str=None, version: str=None, parameters: dict={}):
         if not name:
