@@ -4,9 +4,10 @@ from AIH_SDK import AIHExceptions as AIHE
 
 class Monitor(MonitorsObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.0'):
         super().__init__()
         self._endpoint = 'Monitors'
+        self._version = api_version
 
 
 class MonitorJob(MonitorsObject):
