@@ -3,6 +3,7 @@ from AIH_SDK.Risks.RisksObject import RisksObject
 
 class RiskAssessmentResult(RisksObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.0'):
         super().__init__()
-        self._endpoint = 'RiskAssessmentResults'
\ No newline at end of file
+        self._endpoint = 'RiskAssessmentResults'
+        self._version = api_version
\ No newline at end of file
