@@ -2,6 +2,7 @@ from AIH_SDK.Signals.SignalsObject import SignalsObject
 
 class DataOrigin(SignalsObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.2'):
         super().__init__()
-        self._endpoint = 'DataOrigins'
\ No newline at end of file
+        self._endpoint = 'DataOrigins'
+        self._version = api_version
\ No newline at end of file
