@@ -4,9 +4,10 @@ from AIH_SDK.AIHExceptions import AIHClientException
 
 class Signal(SignalsObject):
 
-    def __init__(self):
+    def __init__(self, api_version='1.2'):
         super().__init__()
         self._endpoint = 'signals'
+        self._version = api_version
 
     
     def post(self):
