@@ -20,14 +20,14 @@ class v2Object(Object):
 
         IN: id (str)          - The id of the object to get.
             parameters (dict) - A dictionary of the parameters to include in the query.
-        
+            api_version (str) - The API version to use. Default is the latest version.
         OUT: self
         """
-        
+            
         if id:
-            self.value = self._client._get(self._api, f'{self._endpoint}/{id}', parameters)
+            self.value = self._client._get(self._api, f'{self._endpoint}/{id}', parameters, self._version)
         else:
-            self.value = self._client._get(self._api, self._endpoint, parameters)
+            self.value = self._client._get(self._api, self._endpoint, parameters, self._version)
     
         return self
 
